@@ -1,4 +1,4 @@
-RelativeWeights = function(price, index.weights) {
+relativeWeights = function(price, index.weights) {
   relative_weights = (price * index.weights) / sum(price * index.weights)
   return(relative_weights)
 }
\ No newline at end of file
